<?php
/**
 * Plugin Name:  Zoomark
 * Description:  Zoomark
 * Version:      1.0
 * Author URI: https://www.zotaro.com
 * Author: Zotaro
  */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Main Zoomark_Wcf7 Class
 */
class Zoomark_Wcf7 {
	/**
	 * Construct class
	 */
	public function __construct() {
		$this->plugin_url       = plugin_dir_url( __FILE__ );
		$this->plugin_path      = plugin_dir_path( __FILE__ );
		$this->version          = '1.0';
		$this->add_actions();
	}

	/**
	 * Add Actions
	 */
	private function add_actions() {
		add_action( 'plugins_loaded', array( $this, 'load_textdomain' ) );
                add_action( 'admin_menu', array( $this, 'zoomark_wcf7_create_menu' ));
		add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_backend' ) );
		add_action( 'wpcf7_editor_panels', array( $this, 'add_panel' ) );
		add_action( 'wpcf7_after_save', array( $this, 'store_meta' ) );
		add_action( 'wpcf7_after_create', array( $this, 'duplicate_form_support' ) );
		add_action( 'wpcf7_submit', array( $this, 'send_to_zoomark' ) );
		add_action( 'admin_notices', array( $this, 'admin_notice' ) );
	}

	/**
	 * Load plugin textdomain.
	 */
	public function load_textdomain() {
		load_plugin_textdomain( 'zoomark-wcf7', false, basename( dirname( __FILE__ ) ) . '/lang' );
	}

        
	/**
	 * Enqueue theme styles and scripts - back-end
	 */
	public function enqueue_backend() {
		wp_enqueue_style( 'zoomark-wcf7-admin-style', $this->plugin_url . 'admin/zoomark-wcf7-admin-style.css' );
	}

        public function zoomark_wcf7_create_menu() {
            add_menu_page(__('Zoomark Settings','zoomark-wcf7'), __('Zoomark Settings','zoomark-wcf7'), 'administrator', __FILE__, array( $this, 'zoomark_settings_page') , plugins_url('/images/icon.png', __FILE__) );
            add_action( 'admin_init', array( $this, 'register_zoomark_plugin_settings' ) );
        }

        public function register_zoomark_plugin_settings() {
                register_setting( 'zoomark-plugin-settings-group', 'account_no', array('default'=>1));
                register_setting( 'zoomark-plugin-settings-group', 'zoomark_url', array('default'=>'http://zoomark.pro/send-try'));
        }
        
        function zoomark_settings_page() {
            ?>
            <div class="wrap">
            <h1><?php esc_html_e( 'Zoomark Settings', 'zoomark-wcf7' );?></h1>

            <form method="post" action="options.php">
                <?php settings_fields( 'zoomark-plugin-settings-group' ); ?>
                <?php do_settings_sections( 'zoomark-plugin-settings-group' ); ?>
                <table class="form-table">
                    <tr valign="top">
                        <th scope="row"><?php esc_html_e( 'Account No.', 'zoomark-wcf7' );?></th>
                        <td><input type="text" name="account_no" value="<?php echo esc_attr( get_option('account_no') ); ?>" /></td>
                    </tr>

                    <tr valign="top">
                        <th scope="row"><?php esc_html_e( 'Zoomark URL', 'zoomark-wcf7' );?></th>
                        <td><input type="text" name="zoomark_url" value="<?php echo esc_attr( get_option('zoomark_url') ); ?>" /></td>
                    </tr>
                </table>

                <?php submit_button(); ?>

            </form>
            </div>
        <?php 
        }
        
	/**
	 * Adds a tab to the editor on the form edit page
	 *
	 * @param array $panels An array of panels. Each panel has a callback function.
	 */
	public function add_panel( $panels ) {
		$panels['zoomark-panel'] = array(
			'title'     => __( 'Zoomark Settings', 'zoomark-wcf7' ),
			'callback'  => array( $this, 'create_panel_inputs' ),
		);
		return $panels;
	}

	/**
	 * Create plugin fields
	 *
	 * @return array of plugin fields: name and type (type is for validation)
	 */
	public function get_plugin_fields() {
		$fields = array(
			array(
				'name' => 'zoomark_name',
				'type' => 'text',
			),
			array(
				'name' => 'zoomark_email',
				'type' => 'text',
			),
			array(
				'name' => 'zoomark_phone',
				'type' => 'text',
			),
			array(
				'name' => 'zoomark_subject',
				'type' => 'text',
			),
			array(
				'name' => 'zoomark_message',
				'type' => 'text',
			),
		);

		return $fields;
	}

	/**
	 * Get all fields values
	 *
	 * @param integer $post_id Form ID.
	 * @return array of fields values keyed by fields name
	 */
	public function get_fields_values( $post_id ) {
		$fields = $this->get_plugin_fields();

		foreach ( $fields as $field ) {
			$values[ $field['name'] ] = get_post_meta( $post_id, '_zoomark_wcf7_' . $field['name'] , true );
		}

		return $values;
	}

	/**
	 * Validate and store meta data
	 *
	 * @param object $contact_form WPCF7_ContactForm Object - All data that is related to the form.
	 */
	public function store_meta( $contact_form ) {
		if ( ! isset( $_POST ) || empty( $_POST ) ) {
			return;
		} else {
			if ( ! wp_verify_nonce( $_POST['zoomark_wcf7_page_metaboxes_nonce'], 'zoomark_wcf7_page_metaboxes' ) ) {
				return;
			}

			$form_id        = $contact_form->id();
			$fields         = $this->get_plugin_fields( $form_id );
			$data           = $_POST['zoomark-wcf7'];

			foreach ( $fields as $field ) {
				$value = isset( $data[ $field['name'] ] ) ? $data[ $field['name'] ] : '';

				switch ( $field['type'] ) {
					case 'text':
					case 'checkbox':
						$value = sanitize_text_field( $value );
						break;

					case 'textarea':
						$value = htmlspecialchars( $value );
						break;

					case 'number':
						$value = intval( $value );
						break;

					case 'url':
						$value = esc_url_raw( $value );
						break;
				}

				update_post_meta( $form_id, '_zoomark_wcf7_' . $field['name'], $value );
			}
		}
	}

	/**
	 * Copy Zoomark setting and assign it to duplicate form
	 *
	 * @param object $contact_form WPCF7_ContactForm Object - All data that is related to the form.
	 */
	public function duplicate_form_support( $contact_form ) {
		$contact_form_id = $contact_form->id();

		if ( ! empty( $_REQUEST['post'] ) && ! empty( $_REQUEST['_wpnonce'] ) ) {
			$post_id = intval( $_REQUEST['post'] );

			$fields = $this->get_plugin_fields();

			foreach ( $fields as $field ) {
				update_post_meta( $contact_form_id, '_zoomark_wcf7_' . $field['name'], get_post_meta( $post_id, '_zoomark_wcf7_' . $field['name'], true ) );
			}
		}
	}

	/**
	 * Verify CF7 dependencies.
	 */
	public function admin_notice() {
		if ( is_plugin_active( 'contact-form-7/wp-contact-form-7.php' ) ) {
			$wpcf7_path = plugin_dir_path( dirname( __FILE__ ) ) . 'contact-form-7/wp-contact-form-7.php';
			$wpcf7_data = get_plugin_data( $wpcf7_path, false, false );
		} else {
			// If CF7 isn't installed and activated, throw an error.
			?>
			<div class="zoomark-wcf7-error error notice">
				<h3>
					<?php esc_html_e( 'Contact Form Zoomark', 'zoomark-wcf7' );?>
				</h3>
				<p>
					<?php esc_html_e( 'Error: Please install and activate Contact Form 7.', 'zoomark-wcf7' );?>
				</p>
			</div>

			<?php
		}
	}

	/**
	 * Add plugin support to browsers that don't support ajax 
	 */
	public function send_to_zoomark( $contact_form ) {
            
                $this->fields = $this->get_fields_values( $contact_form->id() );
                
                $accountId = get_option('account_no');
                $url = empty(get_option('zoomark_url')) ? "http://zoomark.pro/send-try" : get_option('zoomark_url');
                
                $fieldNames = array();
                
                $fieldNames["name"] = !empty($this->fields['zoomark_name']) ? $this->fields['zoomark_name'] : "your-name";
                $fieldNames["email"] = !empty($this->fields['zoomark_email']) ? $this->fields['zoomark_email'] : "your-email";
                $fieldNames["phone"] = !empty($this->fields['zoomark_phone']) ? $this->fields['zoomark_phone'] : "your-phone";
                $fieldNames["subject"] = !empty($this->fields['zoomark_subject']) ? $this->fields['zoomark_subject'] : "your-subject";
                $fieldNames["message"] = !empty($this->fields['zoomark_message']) ? $this->fields['zoomark_message'] : "your-message";
                
                $data = array("name"=>"","email"=>"","phone"=>"","accountId"=>$accountId,"info"=>"");
                
		if ( isset( $this->fields ) ) {
                                        
                    $submission   = WPCF7_Submission::get_instance();

                    if ( $submission ) {
                        $fields = $submission->get_posted_data();

                        $fn = $fieldNames["name"];
                        if(isset($fields[$fn])){
                            $data["name"] = $fields[$fn];
                        }

                        $fn=$fieldNames["email"];
                        if(isset($fields[$fn])){
                            $data["email"] = $fields[$fn];
                        }

                        $fn=$fieldNames["phone"];
                        if(isset($fields[$fn])){
                            $data["phone"] = $fields[$fn];
                        }

                        $fn=$fieldNames["message"];
                        if(isset($fields[$fn])){
                            $data["info"] = $fields[$fn];
                        }

                        $fn = $fieldNames["subject"];
                        if(isset($fields[$fn])){
                            $data["info"] = $fields[$fn]." ".$data["info"];
                        }
                    }
                    
                    $response = wp_remote_post( $url, array('method'=>'POST','timeout'=>45,'body'=>$data));
		}
	}

	/**
	 * Create the panel inputs
	 *
	 * @param  object $post Post object.
	 */
	public function create_panel_inputs( $post ) {
		wp_nonce_field( 'zoomark_wcf7_page_metaboxes', 'zoomark_wcf7_page_metaboxes_nonce' );

		$fields = $this->get_fields_values( $post->id() );
		?>

		<h2>
			<?php esc_html_e( 'Zoomark Settings', 'zoomark-wcf7' );?>
		</h2>

		<fieldset>			
                    <div class="field-wrap field-wrap-use-zoomark-name">
                            <label for="zoomark-wcf7-zoomark-name">
                                    <?php esc_html_e( 'Enter Name Field', 'zoomark-wcf7' );?>
                            </label>
                            <input type="text" id="zoomark_name"  placeholder="Ex. your-name" name="zoomark-wcf7[zoomark_name]" value="<?php echo $fields['zoomark_name'];?>">
                    </div>
                    <div class="field-wrap field-wrap-use-zoomark-email">
                            <label for="zoomark-wcf7-zoomark-email">
                                    <?php esc_html_e( 'Enter Email Field', 'zoomark-wcf7' );?>
                            </label>
                            <input type="text" id="zoomark_email"  placeholder="Ex. your-email" name="zoomark-wcf7[zoomark_email]" value="<?php echo $fields['zoomark_email'];?>">
                    </div>
                    <div class="field-wrap field-wrap-use-zoomark-phone">
                            <label for="zoomark-wcf7-zoomark-phone">
                                    <?php esc_html_e( 'Enter Phone Field', 'zoomark-wcf7' );?>
                            </label>
                            <input type="text" id="zoomark_phone"  placeholder="Ex. your-phone" name="zoomark-wcf7[zoomark_phone]" value="<?php echo $fields['zoomark_phone'];?>">
                    </div>
                    <div class="field-wrap field-wrap-use-zoomark-subject">
                            <label for="zoomark-wcf7-zoomark-subject">
                                    <?php esc_html_e( 'Enter Subject Field', 'zoomark-wcf7' );?>
                            </label>
                            <input type="text" id="zoomark_subject"  placeholder="Ex. your-subject" name="zoomark-wcf7[zoomark_subject]" value="<?php echo $fields['zoomark_subject'];?>">
                    </div>
                    <div class="field-wrap field-wrap-use-zoomark-message">
                            <label for="zoomark-wcf7-zoomark-message">
                                    <?php esc_html_e( 'Enter Message Field', 'zoomark-wcf7' );?>
                            </label>
                            <input type="text" id="zoomark_message"  placeholder="Ex. your-message" name="zoomark-wcf7[zoomark_message]" value="<?php echo $fields['zoomark_message'];?>">
                    </div>
		</fieldset>

		<?php
	}
}

$cf7_redirect = new Zoomark_Wcf7();